# UliPlot
After UliEngineering and UliAcceleration, this library in the Uli series provides convient functions for plotting using matplotlib and other pydata libraries

This library is currently in its Alpha stage and the API is not considered stable

### How to install

```sh
pip3 install git+https://github.com/ulikoehler/UliPlot.git
```

### How to use

```python
from matplotlib import pyplot as plt
import UliPlot as upl
```

Blog posts with specific topics on how to use UliPlot:
- [How to auto-fit Pandas pd.to_excel() XLSX column width](https://techoverflow.net/2021/03/05/how-to-auto-fit-pandas-pd-to_excel-xlsx-column-width/)